==> flask-request-arg-1.0.2.tar.gz: flask-request-arg-1.0.2/setup.py <==
# Copyright 2019 Andrew Rowe.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from codecs import open
from setuptools import setup

VERSION = open("VERSION", "r", encoding="utf-8").read()
LONG_DESCRIPTION = open("README.md", "r", encoding="utf-8").read()

setup(
    name="flask-request-arg",
    version=VERSION,
    description="Easy way to convert Flask request form, JSON and args to route parameters.",
    long_description=LONG_DESCRIPTION,
    long_description_content_type="text/markdown",
    url="https://github.com/Martlark/flask-request-arg",
    download_url="https://github.com/Martlark/flask-request-arg/archive/{version}.tar.gz".format(
        version=VERSION
    ),
    author="Andrew Rowe",
    author_email="rowe.andrew.d@gmail.com",
    license="Apache Software License",
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Framework :: Flask",
        "License :: OSI Approved :: Apache Software License",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Operating System :: POSIX",
        "Operating System :: MacOS",
        "Operating System :: Unix",
        "Operating System :: Microsoft :: Windows",
    ],
    keywords="flask request arguments form json parameters",
    packages=["flask_request_arg"],
    include_package_data=True,
)

==> flask-request-arg-1.0.3.tar.gz: flask-request-arg-1.0.3/setup.py <==
# Copyright 2019 Andrew Rowe.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from codecs import open
from setuptools import setup

VERSION = open("VERSION", "r", encoding="utf-8").read()
LONG_DESCRIPTION = open("README.md", "r", encoding="utf-8").read()

setup(
    name="flask-request-arg",
    version=VERSION,
    description="Easy way to convert Flask request form, header, JSON and parameters to route arguments.",
    long_description=LONG_DESCRIPTION,
    long_description_content_type="text/markdown",
    url="https://github.com/Martlark/flask-request-arg",
    download_url="https://github.com/Martlark/flask-request-arg/archive/{version}.tar.gz".format(
        version=VERSION
    ),
    author="Andrew Rowe",
    author_email="rowe.andrew.d@gmail.com",
    license="Apache Software License",
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Framework :: Flask",
        "License :: OSI Approved :: Apache Software License",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Operating System :: POSIX",
        "Operating System :: MacOS",
        "Operating System :: Unix",
        "Operating System :: Microsoft :: Windows",
    ],
    keywords="flask request arguments form json headers parameters",
    packages=["flask_request_arg"],
    include_package_data=True,
)
